@@ -564,6 +564,10 @@ class RetinaFace:
         else:
             det = np.hstack((pre_det, proposals[:, 4:]))
             det = self.bbox_vote(det)
+            
+        self.ctx.empty_cache() 
+        del net_data
+        
 
         return det, landmarks
 
